# Views API

::: d3_bridge.views.ChartDataView
    options:
      show_source: false
      members:
        - queryset
        - fields
        - geojson
        - geometry_field
        - ordering
        - limit
        - get_queryset
        - filter_queryset
        - get
